measuretools.append_spacer_skip_to_underfull_measure
====================================================

.. autofunction:: abjad.tools.measuretools.append_spacer_skip_to_underfull_measure.append_spacer_skip_to_underfull_measure
